@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HasIdOf.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _HasIdOf.py 14091 2010-01-18 04:42:17Z pez4brian $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -43,4 +43,4 @@ class HasIdOf(HasGrampsId):
     """Rule that checks for a media object with a specific GRAMPS ID"""
 
     name        = _('Media object with <Id>')
-    description = _("Matches a media object with a specified GRAMPS ID")
+    description = _("Matches a media object with a specified Gramps ID")
