@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _HasNameOf.py 20393 2012-09-15 13:29:50Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -62,22 +62,36 @@ class HasNameOf(Rule):
     category    = _('General filters')
 
     def prepare(self, db):
-        self.firstn = self.list[0].upper()
-        self.lastn = self.list[1].upper()
-        self.title = self.list[2].upper()
-        self.suffix = self.list[3].upper()
-        self.calln = self.list[4].upper()
-        self.nick = self.list[5].upper()
-        self.famnick = self.list[10].upper()
-        #surname parts
-        self.prefix = self.list[6].upper()
-        self.surn = self.list[7].upper()
-        self.con = self.list[8].upper()
-        self.patr = self.list[9].upper()
         if len(self.list) >= 12:
             self.regular_expression = bool(int(self.list[11]))
         else:
             self.regular_expression = False
+        if self.regular_expression:
+            self.firstn = self.list[0]
+            self.lastn = self.list[1]
+            self.title = self.list[2]
+            self.suffix = self.list[3]
+            self.calln = self.list[4]
+            self.nick = self.list[5]
+            self.famnick = self.list[10]
+            #surname parts
+            self.prefix = self.list[6]
+            self.surn = self.list[7]
+            self.con = self.list[8]
+            self.patr = self.list[9]
+        else:
+            self.firstn = self.list[0].upper()
+            self.lastn = self.list[1].upper()
+            self.title = self.list[2].upper()
+            self.suffix = self.list[3].upper()
+            self.calln = self.list[4].upper()
+            self.nick = self.list[5].upper()
+            self.famnick = self.list[10].upper()
+            #surname parts
+            self.prefix = self.list[6].upper()
+            self.surn = self.list[7].upper()
+            self.con = self.list[8].upper()
+            self.patr = self.list[9].upper()
         
     def apply(self, db, person):
         for name in [person.get_primary_name()] + person.get_alternate_names():
@@ -95,32 +109,36 @@ class HasNameOf(Rule):
             if not self.patr:
                 valpatr = 1
             if self.regular_expression:
-                if self.firstn and not re.match(self.firstn, name.get_first_name(), re.I|re.U|re.L):
-                    val = 0
-                elif self.lastn and not re.match(self.lastn, name.get_surname(), re.I|re.U|re.L):
-                    val = 0
-                elif self.suffix and not re.match(self.suffix, name.get_suffix(), re.I|re.U|re.L):
-                    val = 0
-                elif self.title and not re.match(self.title, name.get_title(), re.I|re.U|re.L):
-                    val = 0
-                elif self.calln and not re.match(self.calln, name.get_call_name(), re.I|re.U|re.L):
-                    val = 0
-                elif self.nick and not re.match(self.nick, name.get_nick_name(), re.I|re.U|re.L):
-                    val = 0
-                elif self.famnick and not re.match(self.famnick, name.get_family_nick_name(), re.I|re.U|re.L):
-                    val = 0
-                else:
-                    #obtain surnames
-                    for surn in name.get_surname_list():
-                        if self.prefix and re.match(self.prefix, surn.get_prefix(), re.I|re.U|re.L):
-                            valpref = 1
-                        if self.surn and re.match(self.surn, surn.get_surname(), re.I|re.U|re.L):
-                            valsurn = 1
-                        if self.con and re.match(self.con, surn.get_connector(), re.I|re.U|re.L):
-                            valcon = 1
-                        if self.patr and surn.get_origintype().value == NameOriginType.PATRONYMIC \
-                                and re.match(self.patr, surn.get_surname(), re.I|re.U|re.L):
-                            valpatr = 1
+                try:
+                    if self.firstn and not re.match(self.firstn, name.get_first_name(), re.I|re.U|re.L):
+                        val = 0
+                    elif self.lastn and not re.match(self.lastn, name.get_surname(), re.I|re.U|re.L):
+                        val = 0
+                    elif self.suffix and not re.match(self.suffix, name.get_suffix(), re.I|re.U|re.L):
+                        val = 0
+                    elif self.title and not re.match(self.title, name.get_title(), re.I|re.U|re.L):
+                        val = 0
+                    elif self.calln and not re.match(self.calln, name.get_call_name(), re.I|re.U|re.L):
+                        val = 0
+                    elif self.nick and not re.match(self.nick, name.get_nick_name(), re.I|re.U|re.L):
+                        val = 0
+                    elif self.famnick and not re.match(self.famnick, name.get_family_nick_name(), re.I|re.U|re.L):
+                        val = 0
+                    else:
+                        #obtain surnames
+                        for surn in name.get_surname_list():
+                            if self.prefix and re.match(self.prefix, surn.get_prefix(), re.I|re.U|re.L):
+                                valpref = 1
+                            if self.surn and re.match(self.surn, surn.get_surname(), re.I|re.U|re.L):
+                                valsurn = 1
+                            if self.con and re.match(self.con, surn.get_connector(), re.I|re.U|re.L):
+                                valcon = 1
+                            if self.patr and surn.get_origintype().value == NameOriginType.PATRONYMIC \
+                                    and re.match(self.patr, surn.get_surname(), re.I|re.U|re.L):
+                                valpatr = 1
+                except re.error:
+                    #indicate error in the pattern by matching everyone
+                    return True
             else:
                 if self.firstn and name.get_first_name().upper().find(self.firstn) == -1:
                     val = 0
