@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id:_IsLessThanNthGenerationAncestorOf.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _IsLessThanNthGenerationAncestorOf.py 18361 2011-10-23 03:13:50Z paul-franklin $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -51,7 +51,7 @@ class IsLessThanNthGenerationAncestorOf(Rule):
 
     def prepare(self,db):
         self.db = db
-        self.map = {}
+        self.map = set()
         try:
             root_handle = db.get_person_from_gramps_id(self.list[0]).get_handle()
             self.init_ancestor_list(root_handle,0)
@@ -59,18 +59,18 @@ class IsLessThanNthGenerationAncestorOf(Rule):
             pass
 
     def reset(self):
-        self.map = {}
+        self.map.clear()
     
     def apply(self,db,person):
-        return self.map.has_key(person.handle)
+        return person.handle in self.map
 
     def init_ancestor_list(self, handle,gen):
-#        if self.map.has_key(p.get_handle()) == 1:
+#        if p.get_handle() in self.map:
 #            loop_error(self.orig,p)
         if not handle:
             return
         if gen:
-            self.map[handle] = 1
+            self.map.add(handle)
             if gen >= int(self.list[1]):
                 return
         
