@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: _HasCitationBase.py 20270 2012-08-27 09:21:10Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -47,7 +47,6 @@ class HasCitationBase(Rule):
     First parameter is [Volume/page, Date, Confidence]
     """
 
-
     labels      = [ _('Volume/Page:'), 
                     _('Date:'), 
                     _('Confidence:') ]
@@ -63,8 +62,15 @@ class HasCitationBase(Rule):
         except:
             pass
 
-    def apply(self,db,citation):
-        if not self.match_substring(0,citation.get_page()):
+    def apply(self, dbase, object):
+        for citation_handle in object.get_citation_list():
+            citation = dbase.get_citation_from_handle(citation_handle)
+            if self._apply(dbase, citation):
+                return True
+        return False
+    
+    def _apply(self, db, citation):
+        if not self.match_substring(0, citation.get_page()):
             return False
 
         if self.date:
