@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # Simple/_SimpleTable.py
-# $Id: _SimpleTable.py 18584 2011-12-12 13:09:44Z dsblank $
+# $Id: _SimpleTable.py 19753 2012-06-04 00:55:10Z jralls $
 #
 
 """
@@ -32,6 +32,7 @@ import copy
 from gen.ggettext import sgettext as _
 from TransUtils import trans_objclass
 import cPickle as pickle
+import gui.utils
 
 import gen.lib
 import Errors
@@ -109,7 +110,7 @@ class SimpleTable(object):
                 #rectangle = treeview.get_cell_area("0:0", 
                 #x, y = rectangle.x, rectangle.y
                 #func = lambda menu: (x, y, True)
-        elif event.button == 3:
+        elif gui.utils.is_right_click(event):
             button_code = 3
             event_time = event.time
             x = int(event.x)
