@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: const.py.in 20464 2012-09-29 16:32:39Z ldnp $
 
 """
 Provides constants for other modules
@@ -42,11 +42,11 @@ from gen.ggettext import sgettext as _
 #
 #-------------------------------------------------------------------------
 PROGRAM_NAME   = "Gramps"
-if "3.4.1-1" == "@" + "VERSIONSTRING" + "@":
-    VERSION        = "3.4.1"
+if "3.4.2-1" == "@" + "VERSIONSTRING" + "@":
+    VERSION        = "3.4.2"
 else:
-    VERSION        = "3.4.1-1"
-VERSION_TUPLE  = (3, 4, 1)
+    VERSION        = "3.4.2-1"
+VERSION_TUPLE  = (3, 4, 2)
 
 #-------------------------------------------------------------------------
 #
@@ -82,9 +82,9 @@ APP_VCARD       = ["text/x-vcard", "text/x-vcalendar"]
 #
 #-------------------------------------------------------------------------
 if sys.platform == "win32":
-    if sys.prefix == os.path.dirname(os.getcwd()):
-        PREFIXDIR = sys.prefix
-        SYSCONFDIR = os.path.join(sys.prefix, "etc")
+    if sys.prefix.upper() == os.path.dirname(os.getcwd()).upper():
+        PREFIXDIR = sys.prefix.capitalize()
+        SYSCONFDIR = os.path.join(PREFIXDIR, "etc")
 elif  sys.platform == "darwin" and sys.prefix != sys.exec_prefix:
     PREFIXDIR = sys.prefix
     SYSCONFDIR = os.path.join(sys.prefix, "etc")
