@@ -21,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: family.py 20443 2012-09-25 16:49:51Z kulath $
 
 """
 Family object for GRAMPS.
@@ -284,8 +284,7 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         :rtype: list
         """
         check_list = self.media_list + self.attribute_list + \
-            self.lds_ord_list + self.child_ref_list + \
-            self.event_ref_list
+            self.lds_ord_list + self.child_ref_list
         return check_list
 
     def get_note_child_list(self):
@@ -326,7 +325,8 @@ class Family(CitationBase, NoteBase, MediaBase, AttributeBase, LdsOrdBase,
         :returns: Returns the list of objects referencing primary objects.
         :rtype: list
         """
-        return self.get_citation_child_list() 
+        return self.media_list + self.attribute_list + \
+            self.lds_ord_list + self.child_ref_list + self.event_ref_list
 
     def merge(self, acquisition):
         """
