@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: proxybase.py 20276 2012-08-28 17:38:33Z romjerome $
 
 """
 Proxy class for the GRAMPS databases. Filter out all data marked private.
@@ -64,6 +64,7 @@ class ProxyDbBase(DbReadBase):
         self.event_bookmarks = db.event_bookmarks
         self.place_bookmarks = db.place_bookmarks
         self.source_bookmarks = db.source_bookmarks
+        self.citation_bookmarks = db.citation_bookmarks
         self.repo_bookmarks = db.repo_bookmarks
         self.media_bookmarks = db.media_bookmarks
         self.note_bookmarks = db.note_bookmarks
@@ -850,27 +851,31 @@ class ProxyDbBase(DbReadBase):
         return self.bookmarks
 
     def get_family_bookmarks(self):
-        """returns the list of Person handles in the bookmarks"""
+        """returns the list of Family handles in the bookmarks"""
         return self.family_bookmarks
 
     def get_event_bookmarks(self):
-        """returns the list of Person handles in the bookmarks"""
+        """returns the list of Event handles in the bookmarks"""
         return self.event_bookmarks
 
     def get_place_bookmarks(self):
-        """returns the list of Person handles in the bookmarks"""
+        """returns the list of Place handles in the bookmarks"""
         return self.place_bookmarks
 
     def get_source_bookmarks(self):
-        """returns the list of Person handles in the bookmarks"""
+        """returns the list of Source handles in the bookmarks"""
         return self.source_bookmarks
+        
+    def get_citation_bookmarks(self):
+        """returns the list of Citation handles in the bookmarks"""
+        return self.citation_bookmarks
 
     def get_media_bookmarks(self):
-        """returns the list of Person handles in the bookmarks"""
+        """returns the list of Media handles in the bookmarks"""
         return self.media_bookmarks
 
     def get_repo_bookmarks(self):
-        """returns the list of Person handles in the bookmarks"""
+        """returns the list of Repository handles in the bookmarks"""
         return self.repo_bookmarks
 
     def get_note_bookmarks(self):
