@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: backrefmodel.py 16111 2010-11-02 13:19:27Z bmcage $
+# $Id: backrefmodel.py 18548 2011-12-04 17:09:17Z kulath $
 
 #-------------------------------------------------------------------------
 #
@@ -91,6 +92,13 @@ class BackRefModel(gtk.ListStore):
                 gid = p.gramps_id
                 handle = p.handle
                 name = p.get_title()
+            elif dtype == 'Citation':
+                p = self.db.get_citation_from_handle(ref[1])
+                if not p:
+                    continue
+                gid = p.gramps_id
+                handle = p.handle
+                name = p.get_page()
             elif dtype == 'Event':
                 p = self.db.get_event_from_handle(ref[1])
                 if not p:
