@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id$
+# $Id: geography.py 20447 2012-09-25 16:59:16Z noirauds $
 
 #-------------------------------------------------------------------------
 #
@@ -953,21 +953,45 @@ class GeoGraphyView(osmGpsMap, NavigationView):
         """
         Link an existing place using longitude and latitude of location centered
         on the map
+        If we have a place history, we must show all places to avoid an empty
+        place selection in the PlaceSelection.
         """
+        if self.uistate.get_active('Place'):
+            self._createmap(None)
         selector = SelectPlace(self.dbstate, self.uistate, [])
         place = selector.run()
         if place:
             loc = place.get_main_location()
             oldv = (loc.get_country(), loc.get_state(), loc.get_county()) if loc else None
             places_handle = self.dbstate.db.iter_place_handles()
+            nb_places = 0
+            gids = ""
             for place_hdl in places_handle:
                 plce = self.dbstate.db.get_place_from_handle(place_hdl)
                 if plce.get_title() == place.get_title():
-                    self.mark = [None,None,None,None,None,None,None,
-                                 None,None,plce.gramps_id,None,None]
-                    self.select_fct = PlaceSelection(self.uistate, self.dbstate, self.osm,
-                                   self.selection_layer, self.place_list,
-                                   lat, lon, self.__edit_place, oldv)
+                    nb_places += 1
+                    if gids == "":
+                        gids = plce.gramps_id
+                    else:
+                        gids = gids + ", " + plce.gramps_id
+            if nb_places > 1:
+                from QuestionDialog import WarningDialog
+                WarningDialog(
+                      _('You have at least two places with the same title.'),
+                      _("The title of the places is :\n"
+                        "<b>%(title)s</b>\n"
+                        "The following places are similar : %(gid)s\n"
+                        "Eiher you rename the places either you merge them."
+                        "\n\n<b>I can't proceed your request</b>.\n") % {
+                                              'title': plce.get_title(),
+                                              'gid': gids}
+                      )
+            else:
+                self.mark = [None,None,None,None,None,None,None,
+                             None,None,place.gramps_id,None,None]
+                self.select_fct = PlaceSelection(self.uistate, self.dbstate, self.osm,
+                               self.selection_layer, self.place_list,
+                               lat, lon, self.__edit_place, oldv)
 
     def __add_place(self, pcountry, pcounty, pstate, plat, plon):
         """
