@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: grampsmaps.py 18399 2011-11-02 17:15:20Z noirauds $
+# $Id: grampsmaps.py 19847 2012-06-16 09:16:55Z noirauds $
 
 #-------------------------------------------------------------------------
 #
@@ -57,6 +57,7 @@ from gen.ggettext import sgettext as _
 from gen.ggettext import ngettext
 from config import config
 from QuestionDialog import ErrorDialog
+import gui.utils
 
 #-------------------------------------------------------------------------
 #
@@ -294,7 +295,7 @@ class osmGpsMap():
         elif event.button == 2 and event.type == gtk.gdk.BUTTON_RELEASE:
                 self.end_selection = current
                 self.zone_selection = False
-        elif event.button == 3:
+        elif gui.utils.is_right_click(event):
             self.build_nav_menu(osm, event, lat, lon )
         else:
             self.save_center(lat,lon)
@@ -303,8 +304,10 @@ class osmGpsMap():
         """
         Is there a place at this position ?
         """
-        found = False
         mark_selected = []
+        if self.no_show_places_in_status_bar:                                                                        
+            return mark_selected
+        found = False
         oldplace = ""
         for mark in self.places_found:
             # as we are not precise with our hand, reduce the precision
