@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Leak.py 18548 2011-12-04 17:09:17Z kulath $
+# $Id: Leak.py 19753 2012-06-04 00:55:10Z jralls $
 
 """
 Show uncollected objects in a window.
@@ -56,6 +56,7 @@ from gui.plug import tool
 import ManagedWindow
 from QuestionDialog import InfoDialog
 from glade import Glade
+import gui.utils
 
 #-------------------------------------------------------------------------
 #
@@ -116,7 +117,7 @@ class Leak(tool.Tool, ManagedWindow.ManagedWindow):
         if event.type == gtk.gdk._2BUTTON_PRESS and event.button == 1:
             self.referenced_in()
             return True
-        elif event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
+        elif gui.utils.is_right_click(event):
             self.refers_to()
             return True
 
